/*

The NetUsage Project
http://netusage.mozdev.org/

Copyright (C) 2004, NetUsage Project
This extension can be freely distributed under
the terms of the Mozilla Public Licence 1.1
See the licence at http://www.mozilla.org/MPL/

---------
NetUsage ToolItem

*/

const nuISPNormal = 1;
const nuISPRelax = 2;

const nuISPAuthPost = 1;
const nuISPAuthGet = 2;
const nuISPAuthBasic = 3;
const nuISPAuthCustom = 4;

var nuSupportedISPs = {
'bigpond': 'Bigpond Broadband',
'netspace': 'Netspace ADSL',
'iinet': 'iiNet Bliink ADSL',
// 'westnet': 'WestNet ADSL',
'internode': 'Internode',
'optus': 'OptusNet Broadband',
'swiftdsl': 'Swiftbroadband',
'exetel': 'eXeTeL ADSL (has unresolved issues)',

'coditel': 'Coditel.net',
}

function nuFillISPInterface(isp) {
	switch(isp) {
	case 'bigpond':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: '',
			mode: nuISPRelax,
			url: 'https://account.bigpond.com/siteminderagent/nocert/{TIMESTAMP}/smgetcred.scc?TYPE=16777217&REALM=$SM$Toolbar&TARGET=$SM$https%3a%2f%2faccount%2ebigpond%2ecom%2fbroadband%2fusage%2ftoolbar%2ftoolbar%2edo',
			urlAuth: nuISPAuthBasic,

			usagePageUrl: 'https://telstra.com/siteminderagent/login/bdumcustlogin.fcc?TYPE=33554432&REALMOID=&GUID=&SMAUTHREASON=0&TARGET=$SM$https://telstra.com/tcoma/security/login2-sm.asp%3fform=bdumcust_,_AUTH_REDIR=https://account.bigpond.com/broadband/usage/secure/monthlyusage.do',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'username={USERNAME}&password={PASSWORD}',

			strToInt: function (m, s) {
				// bigpond 10GB "unlimited" plan is actually -1 MB ?!
				i = parseInt(s, 10);
				if (i == -1 && m == 'qt') i = 10000;
				return i;
			},

			xpVerify: '/bigpond[@version="1.1"]/usage/account',

			xpUpload: '/bigpond/usage/account/upload',
			xpDownload: '/bigpond/usage/account/download',
			xpLimit: '/bigpond/usage/account/limit',

			xpRecorded: '/bigpond/usage/account/recorded'
		}
	case 'netspace':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: '',
			mode: nuISPNormal,
			url: 'https://usage.netspace.net.au/usage-meter/adslusage?version=2&granularity=MONTH',
			urlAuth: nuISPAuthBasic,

			usagePageUrl: 'http://my.netspace.net.au/usage-meter/timestat0',
			usagePageAuth: nuISPAuthBasic,
			usagePageAuthRealm: 'myNetspace',

			xpError: '/opt/@ERROR',

			xpVerify: '/USAGE[@VERSION="2"]/TRAFFIC',
			xpPlanName: '/USAGE/PLAN/@DESCRIPTION',

			xpStartDate: '/USAGE/@START_DATE',
			xpEndDate: '/USAGE/@END_DATE',

			//xpUpload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Standard"]/@UPLOADS',
			//xpDownload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Standard"]/@DOWNLOADS',
			//xpLimit: '/USAGE/PLAN/LIMIT[@NAME="Standard"]/@MEGABYTES',
			xpUpload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@UPLOADS',
			xpDownload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@DOWNLOADS',
			xpLimit: '/USAGE/PLAN/LIMIT[@NAME="Peak"]/@MEGABYTES',

			//xpUploadF: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Standard"]/@UPLOADS',
			//xpDownloadF: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Standard"]/@DOWNLOADS',
			xpUploadF: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Peak"]/@UPLOADS',
			xpDownloadF: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Peak"]/@DOWNLOADS',

			xpUploadP: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@UPLOADS',
			xpDownloadP: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@DOWNLOADS',
			xpLimitP: '/USAGE/PLAN/LIMIT[@NAME="Peak"]/@MEGABYTES',
			xpUploadPO: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Off Peak"]/@UPLOADS',
			xpDownloadPO: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Off Peak"]/@DOWNLOADS',
			xpLimitPO: '/USAGE/PLAN/LIMIT[@NAME="Off Peak"]/@MEGABYTES',

			xpUploadFP: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Peak"]/@UPLOADS',
			xpDownloadFP: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Peak"]/@DOWNLOADS',
			xpUploadFPO: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Off Peak"]/@UPLOADS',
			xpDownloadFPO: '/USAGE/TRAFFIC[@DESCRIPTION="Free Traffic"]/DATA[@TYPE="Off Peak"]/@DOWNLOADS',

		}
	case 'iinet':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: '',
			mode: nuISPNormal,
			url: 'https://toolbox.iinet.net.au/cgi-bin/volumegraphs.cgi',
			urlAuth: nuISPAuthPost,
			urlAuthPostData: 'action=login&username={USERNAME}&password={PASSWORD}',

			usagePageUrl: 'https://toolbox.iinet.net.au/cgi-bin/volumegraphs.cgi',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'action=login&username={USERNAME}&password={PASSWORD}',

			regexp1P: /Your quota is : ([0-9]+) MB Peak time, ([0-9]+) MB bliinktime[^`]+?volumegraphs\.cgi\?action=showday.+?>([0-9]{2}-[0-9]{2}-[0-9]{4})<\/A>[^`]+?volumegraphs\.cgi\?action=showday.+?>([0-9]{2}-[0-9]{2}-[0-9]{4})<\/A><\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<\/TR>[\n\r ]+<TR ALIGN=right BGCOLOR=#ebebff>[\n\r ]+<TD>&nbsp;<\/TD>[\n\r ]+<TD ALIGN=left><B>Total<\/B><\/TD>[\n\r ]+<TD><B>&nbsp;<\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>/,
			regexpErr: /Please enter your Username and Password/,

			iPlanName: 0,

			iStartDate: 3,
			iEndDate: 4,

			iUploadP: 0,
			iDownloadP: 5,
			iLimitP: 1,
			iUploadPO: 0,
			iDownloadPO: 7,
			iLimitPO: 2,

			iUploadF: 0,
			iDownloadF: 6,
		}
	case 'internode':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: '',
			mode: nuISPNormal,
			url: 'https://accounts.internode.on.net/cgi-bin/padsl-usage',
			urlAuth: nuISPAuthPost,
			urlAuthPostData: 'username={USERNAME}&password={PASSWORD}',

			usagePageUrl: 'https://accounts.internode.on.net/cgi-bin/login',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'username={USERNAME}&password={PASSWORD}&access=Personal_ADSL',

			regexp1: /([0-9\.]+) ([0-9]+) ([0-9\/]+)/,
			regexpErr: /([^\r\n]+)/,

			iPlanName: 0,

			iNextRollDate: 3,

			iUpload: 0,
			iDownload: 1,
			iLimit: 2,
		}
	case 'optus':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: '',
			mode: nuISPNormal,
			url: 'https://myaccount.optusnet.com.au/mydatamonitor/usage.txt',
			urlAuth: nuISPAuthPost,
			urlAuthPostData: 'login={USERNAME}&passwd={PASSWORD}',

			usagePageUrl: 'https://myaccount.optusnet.com.au/mydatamonitor/index.html',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'u=&username={USERNAME}&password={PASSWORD}',

			regexp1: /last=([0-9:\- ]+)[^`]+?plan_limit=([0-9]+)MB[^`]+?plan_name=([^\r\n]+)[^`]+?throttled=([0-9]+)[^`]+?usage=([0-9]+)MB/,
			regexpErr: /error=1[^`]+?reason=([^\r\n]+)/,

			iPlanName: 3,

			iUpload: 0,
			iDownload: 5,
			iLimit: 2,
			iRecorded: 1,
		}
	case 'swiftdsl':
		return {
			id: isp,
			description: 'Please manually enter your usage quota.',
			name: nuSupportedISPs[isp],
			mode: nuISPNormal,
			url: 'https://members.swiftdsl.com.au/usage.php',
			urlAuth: nuISPAuthPost,
			urlAuthPostData: 'username={USERNAME}&password={PASSWORD}',

			usagePageUrl: 'https://members.swiftdsl.com.au/usage.php',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'username={USERNAME}&password={PASSWORD}',

			strToInt: function (m, s) {
				if (m == 'qt') {
					return 16000;
				} else {
					return Math.round(s);
				}
			},

			regexp1P: /<b>([0-9\.]*)<\/b>.*<b>([0-9\.]*)<\/b>.*<b>([0-9\.]*)<\/b>.*<b>([0-9\.]*)<\/b>.*<b>[0-9\.]*<\/b>.*<b>[0-9\.]*<\/b>.*<b>([0-9\.]*)<\/b>.*<b>([0-9\.]*)<\/b>/,
			regexp1: /<b>([0-9\.]*)<\/b>.*<b>([0-9\.]*)<\/b>.*<b>[0-9\.]*<\/b>.*<b>([0-9\.]*)<\/b>/,
			regexpErr: / is invalid Please try again/,

			iPlanName: 0,

			iUpload: 0,
			iDownload: 1,
			iDownloadF: 2,
			iRecorded: 3,
			iLimit: 0,

			iUploadP: 0,
			iUploadPO: 0,

			iDownloadP: 1,
			iDownloadPO: 2,
			iDownloadFP: 3,
			iDownloadFPO: 4,

			iLimitP: 0,
			iLimitPO: 0,
		}
	case 'exetel':
		return {
			id: isp,
			description: 'Please manually enter your usage quota and start day.',
			name: nuSupportedISPs[isp],
			mode: nuISPNormal,
			url: 'https://www.exetel.com.au/members/usage_monthly_query.php',
			urlAuth: nuISPAuthPost,
			urlAuthPostData: 'login_name={USERNAME}&password={PASSWORD}&dologin=1&submit=+Login+',

			usagePageUrl: 'https://www.exetel.com.au/members/usage_monthly_query.php',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthPostData: 'login_name={USERNAME}&password={PASSWORD}&dologin=1&submit=+Login+',


			regexp1P: /Total:[^`]+?<b>([0-9\.]+)<\/b>[^`]+?<b>([0-9\.]+)<\/b>[^`]+?<b>([0-9\.]+)<\/b>[^`]+?<b>([0-9\.]+)<\/b>/,

			regexpErr: /The Service Number and Password you have entered is invalid/,

			iPlanName: 0,

			iUploadP: 3,
			iUploadPO: 1,

			iDownloadP: 4,
			iDownloadPO: 2,
			iDownloadFP: 0,
			iDownloadFPO: 0,

			iLimitP: 0,
			iLimitPO: 0,
		}



	case 'coditel':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			description: 'Please enter the ESN in the username field',
			mode: nuISPRelax,
			url: 'http://www.coditel.net/ENcm_counters.asp?ESN={USERNAME}&action=CheckESN',
			urlAuth: nuISPAuthGet,

			usagePageUrl: 'http://www.coditel.net/ENcm_counters.asp?ESN={USERNAME}&action=CheckESN',
			usagePageAuth: nuISPAuthGet,

			strToInt: function (m, s) {
				if (m == 'qt') {
					return 15000;
				} else {
					// numbers are gigabytes
					// commas are decimal in the page
					d = new Number(s.replace(/,/, '.'));
					return Math.round(d*1000);
				}
			},

			regexp1: /Download used this month : ([0-9,]+) GBytes<br>Upload used this month : ([0-9,]+) GBytes/,

			iPlanName: 0,

			iUpload: 2,
			iDownload: 1,
			iLimit: 0,
		}
	}

	return null;

}
